﻿/**
 * @name umi 的路由配置
 * @description 只支持 path,component,routes,redirect,wrappers,name,icon 的配置
 * @param path  path 只支持两种占位符配置，第一种是动态参数 :id 的形式，第二种是 * 通配符，通配符只能出现路由字符串的最后。
 * @param component 配置 location 和 path 匹配后用于渲染的 React 组件路径。可以是绝对路径，也可以是相对路径，如果是相对路径，会从 src/pages 开始找起。
 * @param routes 配置子路由，通常在需要为多个路径增加 layout 组件时使用。
 * @param redirect 配置路由跳转
 * @param wrappers 配置路由组件的包装组件，通过包装组件可以为当前的路由组件组合进更多的功能。 比如，可以用于路由级别的权限校验
 * @param name 配置路由的标题，默认读取国际化文件 menu.ts 中 menu.xxxx 的值，如配置 name 为 login，则读取 menu.ts 中 menu.login 的取值作为标题
 * @param icon 配置路由的图标，取值参考 https://ant.design/components/icon-cn， 注意去除风格后缀和大小写，如想要配置图标为 <StepBackwardOutlined /> 则取值应为 stepBackward 或 StepBackward，如想要配置图标为 <UserOutlined /> 则取值应为 user 或者 User
 * @doc https://umijs.org/docs/guides/routes
 */
const newMenu = [
  // 分销商页面
  {
    path: '/distributor',
    redirect: '/distributor/account',
  },
  {
    name: 'distributor.account',
    icon: 'icon-zhanghaoguanli',
    path: '/distributor/account',
    access: "isShow",
    component: './Distributor/Account',
  },
  {
    name: 'distributor.appManage',
    icon: 'icon-yingyongguanliyuanguanli',
    path: '/distributor/appManage',
    access: "isShow",
    component: './Distributor/AppManage',
  },
  {
    name: 'distributor.appList',
    icon: 'icon-yingyongguanli',
    path: '/distributor/appList',
    access: "isShow",
    component: './Distributor/AppList',
  },
  {
    name: 'distributor.corpManage',
    icon: 'icon-qiwei_qiwei',
    path: '/distributor/corpManage',
    access: "isShow",
    component: './Distributor/CorpManage',
  },
  
  // {
  //   name: 'distributor.wxMiniApp',
  //   icon: 'icon-weixin',
  //   path: '/distributor/wxMiniApp',
  //   access: "isShow",
  //   component: './Distributor/WxMiniApp',
  // },
  // {
  //   name: 'distributor.dyMiniApp',
  //   icon: 'icon-douyinzhanghao',
  //   path: '/distributor/dyMiniApp',
  //   access: "isShow",
  //   component: './Distributor/DyMiniApp',
  // },
  // 小程序页面
  {
    path: '/miniApp',
    redirect: '/miniApp/book',
  },
  // 用户管理
  {
    path: '/miniApp/user',
    name: 'miniApp.user',
    icon: 'icon-zhanghaoguanli-wx',
    access: 'isShow',
    component: './MiniApp/MiniAppUser',
  },
  // 小说管理
  {
    path: '/miniApp/book',
    name: 'miniApp.book',
    icon: 'icon-xiaoshuo-wx',
    access: 'isShow',
    component: './MiniApp/BookManage',
  },
  // 组件管理
  {
    name: 'miniApp.appManage',
    icon: 'icon-xiaochengxu-wx',
    path: '/miniApp/compConfig',
    access: "isShow",
    component: './MiniApp/CompConfig',
  },
  // 书币充值模板
  {
    name: 'miniApp.payModuleConfig',
    icon: 'icon-taojinbi-wx',
    path: '/miniApp/payModuleConfig',
    access: "isShow",
    component: './MiniApp/ModuleConfig',
  },
  // 数据统计中心
  {
    name:"miniApp.dataManage",
    icon: 'icon-shuju-wx',
    path: '/miniApp/dataManage',
    access: "isShow",
    routes: [
      {
        path: '/miniApp/dataManage',
        redirect: '/miniApp/dataManage/payLog',
      },
      {
        path: '/miniApp/dataManage/payLog',
        name: "payLog",
        component: './MiniApp/PayLog',
      },
      {
        path: '/miniApp/dataManage/readLog',
        name: "readLog",
        component: './MiniApp/ReadLog',
      },
      {
        name: 'consume',
        path: '/miniApp/dataManage/consume',
        component: './MiniApp/Consume',
      }
    ],
  },
  {
    name: 'miniApp.adBack',
    icon: 'icon-guanggaohuichuan-wx',
    path: '/miniApp/adBack',
    access: "isShow",
    component: './MiniApp/AdBack',
  },
]
export default [
  {
    path: '/user',
    layout: false,
    routes: [
      {
        name: 'login',
        path: '/user/login',
        component: './User/Login',
      },
    ],
  },
  {
    path: '/',
    redirect: '/distributor/wxMiniApp',
  },
  {
    path: '*',
    layout: false,
    component: './404',
  },
  ...newMenu
];
