import { api } from '@/services/api';
import { request } from '@umijs/max';
type Page = {
    pageSize: number | string,
    pageNum: number | string
}
interface PublicParams {
    appId: string,//微信小程序组件ID
    appType: string,//小程序类型 1:微信小程序、2：抖音小程序
}
export interface Params extends Page, PublicParams { }
/**全部组件列表 */
export async function appComponentConfigList(params: Params) {
    return request(api + '/admin/appComponentConfig/list', {
        method: 'GET',
        params
    });
}
/**模板切换 */
export async function updateTemplate(params: any) {
    let { templateName, ...data } = params
    return request(api + `/admin/appComponentConfig/updateTemplate/${templateName}`, {
        method: 'PUT',
        params: data
    });
}
/**模板删除 */
export async function remove(params: any) {
    let { templateName, ...data } = params
    return request(api + `/admin/appComponentConfig/remove/${templateName}`, {
        method: 'PUT',
        params: data
    });
}
/**新增修改 */
export async function appComponentConfigAddOrUpdate(data: any) {
    return request(api + '/admin/appComponentConfig/addOrUpdate', {
        method: 'POST',
        data
    });
}

/**小程序页面列表和可配置的组件 */
export async function appComponentConfigGetAppPageList(params: Params) {
    return request(api + '/admin/appComponentConfig/getAppPageList', {
        method: 'GET',
        params
    });
}


type CompParams = {
    appId: string | number,//微信小程序本地 id
    appType: string,//应用类型
    templateName: string,//模板名称
    workDirection: number,//作品方向
}
/**获取短篇热门小说列表组件信息 */
export async function getShortBookHotBooks(params: CompParams) {
    return request(api + '/admin/appComponentConfig/getHotBooks', {
        method: 'GET',
        params
    });
}



/**获取短篇首页banners列表组件信息 */
export async function getShortBookBanners(params: CompParams) {
    return request(api + '/admin/appComponentConfig/getBanners', {
        method: 'GET',
        params
    });
}



/**获取热门分类列表组件信息 */
export async function getHotCategory(params: CompParams) {
    return request(api + '/admin/appComponentConfig/getHotCategory', {
        method: 'GET',
        params
    });
}

